# Lark MCP

A Model Context Protocol (MCP) server for Lark.


```json

{
  "mcpServers": {
    "lark-mcp": {
      "env": {
        "APP_ID": "APP_ID",
        "APP_SECRET": "APP_SECRET"
      },
      "command": "uvx",
      "args": [
        "lark-mcp"
      ]
    }
  }
}
```